@@ -3,7 +3,7 @@
 # Copyright (c) 2004, 2006 Sean C. Gillies
 # Copyright (c) 2007 STFC <http://www.stfc.ac.uk>
 #
-# Authors :
+# Authors:
 #          Dominic Lowe <d.lowe@rl.ac.uk>
 #
 # Contact email: d.lowe@rl.ac.uk
@@ -11,17 +11,18 @@
 
 # NOTE: Does not conform to new interfaces yet #################
 
-from .wcsBase import WCSBase, WCSCapabilitiesReader, ServiceException
-from owslib.util import openURL, testXMLValue
-from urllib.parse import urlencode
-from owslib.etree import etree
-import os
 import errno
+import logging
+import os
+from urllib.parse import urlencode
+
+from .wcsBase import WCSBase, WCSCapabilitiesReader, ServiceException
+from owslib.etree import etree
 from owslib.coverage import wcsdecoder
 from owslib.crs import Crs
+from owslib.util import openURL, testXMLValue
 
-import logging
-from owslib.util import log
+LOGGER = logging.getLogger(__name__)
 
 
 class Namespaces_1_1_0():
@@ -52,7 +53,7 @@ class WebCoverageService_1_1_0(WCSBase):
             raise KeyError("No content named %s" % name)
 
     def __init__(self, url, xml, cookies, auth=None, timeout=30, headers=None):
-        super(WebCoverageService_1_1_0, self).__init__(auth=auth, headers=headers)
+        super(WebCoverageService_1_1_0, self).__init__(auth=auth, timeout=timeout, headers=headers)
 
         self.url = url
         self.cookies = cookies
@@ -156,11 +157,10 @@ class WebCoverageService_1_1_0(WCSBase):
         if store = true, returns a coverages XML file
         if store = false, returns a multipart mime
         """
-        if log.isEnabledFor(logging.DEBUG):
-            msg = 'WCS 1.1.0 DEBUG: Parameters passed to GetCoverage: identifier={}, bbox={}, time={}, format={}, rangesubset={}, gridbaseCRS={}, gridtype={}, gridCS={}, gridorigin={}, gridoffsets={}, method={}, other_arguments={}'  # noqa
-            log.debug(msg.format(
-                identifier, bbox, time, format, rangesubset, gridbaseCRS, gridtype, gridCS,
-                gridorigin, gridoffsets, method, str(kwargs)))
+        msg = 'WCS 1.1.0 DEBUG: Parameters passed to GetCoverage: identifier={}, bbox={}, time={}, format={}, rangesubset={}, gridbaseCRS={}, gridtype={}, gridCS={}, gridorigin={}, gridoffsets={}, method={}, other_arguments={}'  # noqa
+        LOGGER.debug(msg.format(
+            identifier, bbox, time, format, rangesubset, gridbaseCRS, gridtype, gridCS,
+            gridorigin, gridoffsets, method, str(kwargs)))
 
         if method == 'Get':
             method = self.ns.WCS_OWS('Get')
@@ -176,7 +176,7 @@ class WebCoverageService_1_1_0(WCSBase):
         request['identifier'] = identifier
         # request['identifier'] = ','.join(identifier)
         if bbox:
-            request['boundingbox'] = ','.join([repr(x) for x in bbox])
+            request['boundingbox'] = ','.join([str(x) for x in bbox])
         if time:
             request['timesequence'] = ','.join(time)
         request['format'] = format
